==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaKontoBankoweKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DpsJednostkaKontoBankoweKey extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpsJednostkaId;

    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.KONTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kontoId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_KONTO_BANKOWE.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @return DPS_JEDNOSTKA_KONTO_BANKOWE.KONTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKontoId() {
        return kontoId;
    }

    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaKontoBankoweKey other = (DpsJednostkaKontoBankoweKey) that;
        return (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()))
            && (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append(", kontoId=").append(kontoId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DpsJednostkaKontoBankoweKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DpsJednostkaKontoBankoweKey extends GenericDPSObject {
    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.DPS_JEDNOSTKA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpsJednostkaId;

    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.KONTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kontoId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DPS_JEDNOSTKA_KONTO_BANKOWE.DPS_JEDNOSTKA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpsJednostkaId() {
        return dpsJednostkaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.DPS_JEDNOSTKA_ID
     *
     * @param dpsJednostkaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpsJednostkaId(Long dpsJednostkaId) {
        this.dpsJednostkaId = dpsJednostkaId;
    }

    /**
     * @return DPS_JEDNOSTKA_KONTO_BANKOWE.KONTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKontoId() {
        return kontoId;
    }

    /**
     * DPS_JEDNOSTKA_KONTO_BANKOWE.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DpsJednostkaKontoBankoweKey other = (DpsJednostkaKontoBankoweKey) that;
        return (this.getDpsJednostkaId() == null ? other.getDpsJednostkaId() == null : this.getDpsJednostkaId().equals(other.getDpsJednostkaId()))
            && (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDpsJednostkaId() == null) ? 0 : getDpsJednostkaId().hashCode());
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", dpsJednostkaId=").append(dpsJednostkaId);
        sb.append(", kontoId=").append(kontoId);
        sb.append("]");
        return sb.toString();
    }
}
